@@ -1983,18 +1983,18 @@ ask_cancel (void)
 	return (res == GTK_RESPONSE_YES);
 }
 
-static void
-do_cancel (void)
+static gboolean
+handle_cancel (void)
 {
 	gboolean cancelled;
 
 	if (cancel == CANCEL_NONE) {
-		return;
+		return FALSE;
 	}
 
 	if (cancel == CANCEL_MAKE_ISO) {
 		nautilus_burn_make_iso_cancel ();
-		return;
+		return TRUE;
 	}
 
 	cancelled = nautilus_burn_recorder_cancel (recorder, TRUE);
@@ -2003,23 +2003,26 @@ do_cancel (void)
 		if (ask_cancel () == TRUE) {
 			/* do the dangerous cancel */
 			nautilus_burn_recorder_cancel (recorder, FALSE);
+		} else {
+			return TRUE;
 		}
 	}
+
+	return TRUE;
 }
 
 static gboolean
 handle_delete_event (GtkWidget	     *widget,
 		     GdkEventAny     *event)
 {
-	do_cancel ();
-	return TRUE;
+	return handle_cancel ();
 }
 
 static void
 cancel_clicked (GtkButton *button,
 		gpointer   data)
 {
-	do_cancel ();
+	handle_cancel ();
 }
 
 static void
